@@ -58,6 +58,25 @@ MULTIPLE_EXTENSION_FOR_MIMETYPE_OF_ANNEX_WARNING = "Could not determine an exten
 ITEM_SOAP_CREATED = "create_item_using_imio_pm_ws_soap"
 
 
+def setup_user_in_the_name_of(portal, member):
+    """ """
+    # remove AUTHENTICATED_USER during adopt_user to avoid
+    # breaking utils.get_current_user_id
+    original_auth_user = portal.REQUEST.get("AUTHENTICATED_USER")
+    if original_auth_user:
+        portal.REQUEST["AUTHENTICATED_USER"] = None
+
+    oldsm = getSecurityManager()
+    newSecurityManager(portal.REQUEST, member)
+    return oldsm, original_auth_user
+
+
+def teardown_user_in_the_name_of(portal, oldsm, original_auth_user):
+    """ """
+    setSecurityManager(oldsm)
+    portal.REQUEST["AUTHENTICATED_USER"] = original_auth_user
+
+
 class SOAPView(BrowserView):
     """
       class delivering SOAP methods for Products.PloneMeeting
@@ -439,8 +458,7 @@ class SOAPView(BrowserView):
         res = []
         try:
             if inTheNameOf:
-                oldsm = getSecurityManager()
-                newSecurityManager(portal.REQUEST, member)
+                oldsm, original_auth_user = setup_user_in_the_name_of(portal, member)
 
             # force to use the 'MeetingItem' meta_type to be sure that attributes here above exist on found elements
             params['meta_type'] = 'MeetingItem'
@@ -575,7 +593,7 @@ class SOAPView(BrowserView):
         finally:
             # fallback to original user calling the SOAP method
             if inTheNameOf:
-                setSecurityManager(oldsm)
+                teardown_user_in_the_name_of(portal, oldsm, original_auth_user)
         return res
 
     def _getItemTemplate(self, itemUID, templateId, inTheNameOf):
@@ -602,8 +620,7 @@ class SOAPView(BrowserView):
         # if we are creating an item inTheNameOf, use this user for the rest of the process
         try:
             if inTheNameOf:
-                oldsm = getSecurityManager()
-                newSecurityManager(portal.REQUEST, member)
+                oldsm, original_auth_user = setup_user_in_the_name_of(portal, member)
 
             # search for the item, this will also check if the user can actually access it
             catalog = api.portal.get_tool('portal_catalog')
@@ -636,7 +653,7 @@ class SOAPView(BrowserView):
         finally:
             # fallback to original user calling the SOAP method
             if inTheNameOf:
-                setSecurityManager(oldsm)
+                teardown_user_in_the_name_of(portal, oldsm, original_auth_user)
         return res
 
     def _getExtraInfosFields(self, item):
@@ -680,8 +697,7 @@ class SOAPView(BrowserView):
         res = []
         try:
             if inTheNameOf:
-                oldsm = getSecurityManager()
-                newSecurityManager(portal.REQUEST, member)
+                oldsm, original_auth_user = setup_user_in_the_name_of(portal, member)
 
             brains = cfg.getMeetingsAcceptingItems()
             for brain in brains:
@@ -696,7 +712,8 @@ class SOAPView(BrowserView):
         finally:
             # fallback to original user calling the SOAP method
             if inTheNameOf:
-                setSecurityManager(oldsm)
+                teardown_user_in_the_name_of(portal, oldsm, original_auth_user)
+
         logger.info('MeetingConfig at %s SOAP accessed by "%s" to get meetings accepting items.' %
                     (cfg.absolute_url_path(), memberId))
         return res
@@ -867,8 +884,7 @@ class SOAPView(BrowserView):
         try:
             # if we are creating an item inTheNameOf, use this user for the rest of the process
             if inTheNameOf:
-                oldsm = getSecurityManager()
-                newSecurityManager(portal.REQUEST, member)
+                oldsm, original_auth_user = setup_user_in_the_name_of(portal, member)
 
             # get or create the meetingFolder the item will be created in
             # if the user does not have a memberArea
@@ -1096,7 +1112,7 @@ class SOAPView(BrowserView):
         finally:
             # fallback to original user calling the SOAP method
             if inTheNameOf:
-                setSecurityManager(oldsm)
+                teardown_user_in_the_name_of(portal, oldsm, original_auth_user)
         return item.UID(), warnings
 
     def _mayAccessAdvancedFunctionnalities(self):
@@ -1107,7 +1123,7 @@ class SOAPView(BrowserView):
           MeetingConfig to be able to use 'inTheNameOf' or a 'Manager'.
         '''
         tool = api.portal.get_tool('portal_plonemeeting')
-        if tool.userIsAmong(['meetingmanagers']) or tool.isManager(self.context, realManagers=True):
+        if tool.userIsAmong(['meetingmanagers']) or tool.isManager(realManagers=True):
             return True
 
         return False
